@@ -60,37 +60,45 @@ class AristonDevice(ABC):
             self.consumption_type,
         )
 
-    def get_system_type(self) -> SystemType:
+    @property
+    def system_type(self) -> SystemType:
         """Get device system type wrapper"""
         return SystemType(self.attributes.get(DeviceAttribute.SYS, SystemType.UNKNOWN))
 
-    def get_whe_type(self) -> WheType:
+    @property
+    def whe_type(self) -> WheType:
         """Get device whe type wrapper"""
         return WheType(
             self.attributes.get(VelisDeviceAttribute.WHE_TYPE, WheType.Unknown)
         )
 
-    def get_gateway(self) -> str:
+    @property
+    def gateway(self) -> str:
         """Get device gateway wrapper"""
         return self.gw
 
-    def get_has_metering(self) -> Optional[bool]:
+    @property
+    def has_metering(self) -> Optional[bool]:
         """Get device has metering wrapper"""
         return self.features.get(DeviceFeatures.HAS_METERING, None)
 
-    def get_name(self) -> Optional[str]:
+    @property
+    def name(self) -> Optional[str]:
         """Get device name wrapper"""
         return self.attributes.get(DeviceAttribute.NAME, None)
 
-    def get_dhw_mode_changeable(self) -> Optional[bool]:
+    @property
+    def dhw_mode_changeable(self) -> Optional[bool]:
         """Get device domestic hot water mode changeable wrapper"""
         return self.features.get(DeviceFeatures.DHW_MODE_CHANGEABLE, None)
 
-    def get_serial_number(self) -> Optional[str]:
+    @property
+    def serial_number(self) -> Optional[str]:
         """Get device serial number wrapper"""
         return self.attributes.get(DeviceAttribute.SN, None)
 
-    def get_firmware_version(self) -> Optional[str]:
+    @property
+    def firmware_version(self) -> Optional[str]:
         """Get device firmware version wrapper"""
         return self.attributes.get(GalevoDeviceAttribute.FW_VER, None)
 
@@ -104,12 +112,13 @@ class AristonDevice(ABC):
         if features is not None:
             self.features = features
 
-    def get_water_heater_current_mode_text(self) -> str:
+    @property
+    def water_heater_current_mode_text(self) -> str:
         """Get water heater current mode text"""
-        mode = self.get_water_heater_mode_value()
-        if mode in self.get_water_heater_mode_options():
-            index = self.get_water_heater_mode_options().index(mode)
-            return self.get_water_heater_mode_operation_texts()[index]
+        mode = self.water_heater_mode_value
+        if mode in self.water_heater_mode_options:
+            index = self.water_heater_mode_options.index(mode)
+            return self.water_heater_mode_operation_texts[index]
         return "UNKNOWN"
 
     @abstractmethod
@@ -122,48 +131,57 @@ class AristonDevice(ABC):
         """Async update the device states from the cloud"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_current_temperature(self) -> Optional[float]:
+    def water_heater_current_temperature(self) -> Optional[float]:
         """Abstract method for get water heater current temperature"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_minimum_temperature(self) -> float:
+    def water_heater_minimum_temperature(self) -> float:
         """Abstract method for get water heater minimum temperature"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_target_temperature(self) -> Optional[float]:
+    def water_heater_target_temperature(self) -> Optional[float]:
         """Abstract method for get water heater target temperature"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_maximum_temperature(self) -> Optional[float]:
+    def water_heater_maximum_temperature(self) -> Optional[float]:
         """Abstract method for get water heater maximum temperature"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_temperature_decimals(self) -> int:
+    def water_heater_temperature_decimals(self) -> int:
         """Abstract method for get water heater temperature decimals"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_temperature_unit(self) -> str:
+    def water_heater_temperature_unit(self) -> str:
         """Abstract method for get water heater temperature unit"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_mode_operation_texts(self) -> list[str]:
+    def water_heater_mode_operation_texts(self) -> list[str]:
         """Abstract method for get water heater operation texts"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_mode_options(self) -> list[int]:
+    def water_heater_mode_options(self) -> list[int]:
         """Abstract method for get water heater mode options"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_mode_value(self) -> Optional[int]:
+    def water_heater_mode_value(self) -> Optional[int]:
         """Abstract method for get water heater mode value"""
         raise NotImplementedError
 
@@ -177,8 +195,9 @@ class AristonDevice(ABC):
         """Abstract method for async set water temperature"""
         raise NotImplementedError
 
+    @property
     @abstractmethod
-    def get_water_heater_temperature_step(self) -> int:
+    def water_heater_temperature_step(self) -> int:
         """Abstract method for get water heater temperature step"""
         raise NotImplementedError
 
@@ -192,60 +211,64 @@ class AristonDevice(ABC):
         """Abstract method for async set water heater operation mode"""
         raise NotImplementedError
 
-    def get_consumption_sequence_last_changed_utc(self) -> dt.datetime:
-        """Get consumption sequence last changed in utc"""
-        return self.consumption_sequence_last_changed_utc
-
-    def get_central_heating_total_energy_consumption(self) -> Any:
+    @property
+    def central_heating_total_energy_consumption(self) -> Any:
         """Get central heating total energy consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.CENTRAL_HEATING_TOTAL_ENERGY,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_domestic_hot_water_total_energy_consumption(self) -> Any:
+    @property
+    def domestic_hot_water_total_energy_consumption(self) -> Any:
         """Get domestic hot water total energy consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.DOMESTIC_HOT_WATER_TOTAL_ENERGY,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_central_heating_gas_consumption(self) -> Any:
+    @property
+    def central_heating_gas_consumption(self) -> Any:
         """Get central heating gas consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.CENTRAL_HEATING_GAS,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_domestic_hot_water_heating_pump_electricity_consumption(self) -> Any:
+    @property
+    def domestic_hot_water_heating_pump_electricity_consumption(self) -> Any:
         """Get domestic hot water heating pump electricity consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.DOMESTIC_HOT_WATER_HEATING_PUMP_ELECTRICITY,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_domestic_hot_water_resistor_electricity_consumption(self) -> Any:
+    @property
+    def domestic_hot_water_resistor_electricity_consumption(self) -> Any:
         """Get domestic hot water resistor electricity consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.DOMESTIC_HOT_WATER_RESISTOR_ELECTRICITY,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_domestic_hot_water_gas_consumption(self) -> Any:
+    @property
+    def domestic_hot_water_gas_consumption(self) -> Any:
         """Get domestic hot water gas consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.DOMESTIC_HOT_WATER_GAS,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_central_heating_electricity_consumption(self) -> Any:
+    @property
+    def central_heating_electricity_consumption(self) -> Any:
         """Get central heating electricity consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.CENTRAL_HEATING_ELECTRICITY,
             ConsumptionTimeInterval.LAST_DAY,
         )
 
-    def get_domestic_hot_water_electricity_consumption(self) -> Any:
+    @property
+    def domestic_hot_water_electricity_consumption(self) -> Any:
         """Get domestic hot water electricity consumption"""
         return self._get_consumption_sequence_last_value(
             ConsumptionType.DOMESTIC_HOT_WATER_ELECTRICITY,
@@ -264,7 +287,7 @@ class AristonDevice(ABC):
 
         return None
 
-    def _update_energy(self, old_consumptions_sequences: list[dict[str, Any]]) -> None:
+    def _update_energy(self, old_consumptions_sequences: Optional[list[dict[str, Any]]]) -> None:
         """Update the device energy settings"""
         if (
             self.custom_features.get(
@@ -298,17 +321,16 @@ class AristonDevice(ABC):
     def _set_energy_features(self):
         """Set energy features"""
         for consumption_type in ConsumptionType:
-            if consumption_type.name is not None:
-                if (
-                    self._get_consumption_sequence_last_value(
-                        consumption_type,
-                        ConsumptionTimeInterval.LAST_DAY,
-                    )
-                    != None
-                ):
-                    self.custom_features[consumption_type.name] = True
-                else:
-                    self.custom_features[consumption_type.name] = False
+            if (
+                self._get_consumption_sequence_last_value(
+                    consumption_type,
+                    ConsumptionTimeInterval.LAST_DAY,
+                )
+                is not None
+            ):
+                self.custom_features[consumption_type.name] = True
+            else:
+                self.custom_features[consumption_type.name] = False
 
     def are_device_features_available(
         self,
@@ -317,10 +339,10 @@ class AristonDevice(ABC):
         whe_types: Optional[list[WheType]],
     ) -> bool:
         """Checks features availability"""
-        if system_types is not None and self.get_system_type() not in system_types:
+        if system_types is not None and self.system_type not in system_types:
             return False
 
-        if whe_types is not None and self.get_whe_type() not in whe_types:
+        if whe_types is not None and self.whe_type not in whe_types:
             return False
 
         if device_features is not None:
